diff --git a/build/psalm-baseline.xml b/build/psalm-baseline.xml
index da22e228cd4..c7e2974b16b 100644
--- a/build/psalm-baseline.xml
+++ b/build/psalm-baseline.xml
@@ -4404,7 +4404,8 @@
IImage|null
-
+
+ $quota
$this->lastLogin
@@ -4528,6 +4529,14 @@
\Test\Util\User\Dummy
+
+
+ OC_Helper::computerFileSize($userQuota)
+
+
+ float
+
+
$this->request->server
@@ -4625,4 +4634,12 @@
PreconditionNotMetException
+
+
+ \OC_Helper::computerFileSize($str)
+
+
+ float|false
+
+
diff --git a/lib/private/legacy/OC_Util.php b/lib/private/legacy/OC_Util.php
index 3a3b634e522..84416c21337 100644
--- a/lib/private/legacy/OC_Util.php
+++ b/lib/private/legacy/OC_Util.php
@@ -158,7 +158,7 @@ class OC_Util {
* Get the quota of a user
*
* @param IUser|null $user
- * @return int|\OCP\Files\FileInfo::SPACE_UNLIMITED|false Quota bytes
+ * @return float Quota bytes
*/
public static function getUserQuota(?IUser $user) {
if (is_null($user)) {
diff --git a/lib/private/legacy/OC_Helper.php b/lib/private/legacy/OC_Helper.php
index ba9ac13b216..cf3f157b8a7 100644
--- a/lib/private/legacy/OC_Helper.php
+++ b/lib/private/legacy/OC_Helper.php
@@ -95,7 +95,7 @@ class OC_Helper {
/**
* Make a computer file size
* @param string $str file size in human readable format
* @return int|false a file size in bytes
*
* Makes 2kB to 2048.
*
@@ -104,7 +104,7 @@ class OC_Helper {
public static function computerFileSize($str) {
$str = strtolower($str);
if (is_numeric($str)) {
- return (int)$str;
+ return (float)$str;
}
$bytes_array = [
@@ -131,7 +131,7 @@ class OC_Helper {
$bytes = round($bytes);
- return (int)$bytes;
+ return $bytes;
}
/**
@@ -605,7 +605,7 @@ class OC_Helper {
/**
* Get storage info including all mount points and quota
*/
- private static function getGlobalStorageInfo(int $quota, IUser $user, IMountPoint $mount): array {
+ private static function getGlobalStorageInfo(float $quota, IUser $user, IMountPoint $mount): array {
$rootInfo = \OC\Files\Filesystem::getFileInfo('', 'ext');
$used = $rootInfo['size'];
if ($used < 0) {
@@ -95,7 +95,7 @@ class OC_Helper {
* Make a computer file size
* @param string $str file size in human readable format
- * @return int|false a file size in bytes
+ * @return float|bool a file size in bytes
*
* Makes 2kB to 2048.